==> kubernetes-model-autoscaling-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HorizontalPodAutoscalerStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HorizontalPodAutoscalerStatusBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusBuilder>{
  public HorizontalPodAutoscalerStatusBuilder() {
    this(false);
  }
  public HorizontalPodAutoscalerStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new HorizontalPodAutoscalerStatus(), validationEnabled);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HorizontalPodAutoscalerStatus(), validationEnabled);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus instance) {
    this(fluent, instance, false);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentMetrics(instance.getCurrentMetrics()); 
    fluent.withCurrentReplicas(instance.getCurrentReplicas()); 
    fluent.withDesiredReplicas(instance.getDesiredReplicas()); 
    fluent.withLastScaleTime(instance.getLastScaleTime()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    this.validationEnabled = validationEnabled; 
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus instance) {
    this(instance,false);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withCurrentMetrics(instance.getCurrentMetrics()); 
    this.withCurrentReplicas(instance.getCurrentReplicas()); 
    this.withDesiredReplicas(instance.getDesiredReplicas()); 
    this.withLastScaleTime(instance.getLastScaleTime()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus build() {
    HorizontalPodAutoscalerStatus buildable = new HorizontalPodAutoscalerStatus(fluent.getConditions(),fluent.getCurrentMetrics(),fluent.getCurrentReplicas(),fluent.getDesiredReplicas(),fluent.getLastScaleTime(),fluent.getObservedGeneration());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HorizontalPodAutoscalerStatusBuilder that = (HorizontalPodAutoscalerStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-autoscaling-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/HorizontalPodAutoscalerStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HorizontalPodAutoscalerStatusBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusBuilder>{
  public HorizontalPodAutoscalerStatusBuilder() {
    this(false);
  }
  public HorizontalPodAutoscalerStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new HorizontalPodAutoscalerStatus(), validationEnabled);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HorizontalPodAutoscalerStatus(), validationEnabled);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus instance) {
    this(fluent, instance, false);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentMetrics(instance.getCurrentMetrics()); 
    fluent.withCurrentReplicas(instance.getCurrentReplicas()); 
    fluent.withDesiredReplicas(instance.getDesiredReplicas()); 
    fluent.withLastScaleTime(instance.getLastScaleTime()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus instance) {
    this(instance,false);
  }
  public HorizontalPodAutoscalerStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withCurrentMetrics(instance.getCurrentMetrics()); 
    this.withCurrentReplicas(instance.getCurrentReplicas()); 
    this.withDesiredReplicas(instance.getDesiredReplicas()); 
    this.withLastScaleTime(instance.getLastScaleTime()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.HorizontalPodAutoscalerStatus build() {
    HorizontalPodAutoscalerStatus buildable = new HorizontalPodAutoscalerStatus(fluent.getConditions(),fluent.getCurrentMetrics(),fluent.getCurrentReplicas(),fluent.getDesiredReplicas(),fluent.getLastScaleTime(),fluent.getObservedGeneration());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HorizontalPodAutoscalerStatusBuilder that = (HorizontalPodAutoscalerStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
